==> zbxe.beta.0.2.7.tgz: zbxe/modules/widget/lang/zh-CN.lang.php <==
<?php
    /**
     * @file   modules/widget/lang/zh-CN.lang.php
     * @author zero <zero@nzeo.com>
     * @brief  控件(widget) 模块语言包
     **/

    $lang->cmd_generate_code = '生成代码';

    $lang->widget_name = '控件名称';
    $lang->widget_maker = '控件作者';
    $lang->widget_history = '更新事项';
    $lang->widget_info = '控件信息';
    $lang->widget_code = '代码';
    $lang->widget_cache = '缓冲';

    $lang->widget_fix_width = '固定大小';
    $lang->widget_width = '宽度';
    $lang->widget_position = '位置';
    $lang->widget_position_none = '换行';
    $lang->widget_position_left = '左对齐';
    $lang->widget_position_right = '右对齐';
    $lang->widget_margin = '边距';
    $lang->widget_margin_top = '上';
    $lang->widget_margin_right = '右';
    $lang->widget_margin_bottom = '下';
    $lang->widget_margin_left= '左';
    $lang->about_widget_fix_width = '选择此项将固定控件显示宽度。';
    $lang->about_widget_width = '请输入宽度大小。';
    $lang->about_widget_position = '想要横向显示多个控件时，请选择位置。';
    $lang->about_widget_margin = '想要横向显示多个控件时，请设置边距。';
    $lang->about_widget_cache = '指定的时间内可以利用已缓冲的数据。';

    $lang->generated_code = '已生成的代码';

    $lang->msg_widget_is_not_exists = '找不到%s控件！';
    $lang->msg_widget_object_is_null = '无法生成%s控件对象！';
    $lang->msg_widget_proc_is_null = '不能执行%s控件的 proc()！';

    $lang->about_widget_code = '输入被选控件所需要的下列各项后，按『代码生成』按钮，即可在页面下方获得可以用在布局模版代码片断。';
    $lang->about_widget_code_in_page = '输入下列各项必要值后，按“添加”按钮，即可把控件插入到页面当中。';
    $lang->about_widget = "控件是在布局或页面模块中使用的一种小部件。\n不仅可以关联内部模块或外部open api，而且通过设置可以用在多种用途。\n即使不使用Zeroboard XE的页面模块或布局模块，也可以通过『代码生成』功能直接可以添加相应控件。";

    $lang->cmd_content_insert = "添加内容";
    $lang->cmd_box_widget_insert = "添加控件盒";
    $lang->cmd_remove_all_widgets  = "清空内容";

    $lang->cmd_widget_size = "大小";
    $lang->cmd_widget_align = "对齐";
    $lang->cmd_widget_align_left = "左对齐";
    $lang->cmd_widget_align_right = "右对齐";
    $lang->cmd_widget_margin = "外边距";
    $lang->cmd_widget_padding = "内填充";
    $lang->cmd_widget_border = "边框";
    $lang->cmd_widget_border_solid = "实线";
    $lang->cmd_widget_border_dotted = "点线";
    $lang->cmd_widget_background_color = "背景色";
    $lang->cmd_widget_background_image_url = "背景图片";
    $lang->cmd_widget_background_image_repeat = "平铺";
    $lang->cmd_widget_background_image_no_repeat = "固定";
    $lang->cmd_widget_background_image_x_repeat = "横向平铺";
    $lang->cmd_widget_background_image_y_repeat = "纵向平铺";
    $lang->cmd_widget_background_image_x = "水平位置";
    $lang->cmd_widget_background_image_y = "垂直位置";
?>

==> zbxe.beta.0.2.8.tgz: zbxe/modules/widget/lang/zh-CN.lang.php <==
<?php
    /**
     * @file   modules/widget/lang/zh-CN.lang.php
     * @author zero <zero@nzeo.com>
     * @brief  控件(widget) 模块语言包
     **/

    $lang->cmd_generate_code = '生成代码';

    $lang->widget_name = '控件名称';
    $lang->widget_maker = '控件作者';
    $lang->widget_history = '更新事项';
    $lang->widget_info = '控件信息';
    $lang->widget_code = '代码';
    $lang->widget_cache = '缓冲';

    $lang->widget_fix_width = '固定大小';
    $lang->widget_width = '宽度';
    $lang->widget_position = '位置';
    $lang->widget_position_none = '换行';
    $lang->widget_position_left = '左对齐';
    $lang->widget_position_right = '右对齐';
    $lang->widget_margin = '边距';
    $lang->widget_margin_top = '上';
    $lang->widget_margin_right = '右';
    $lang->widget_margin_bottom = '下';
    $lang->widget_margin_left= '左';
    $lang->about_widget_fix_width = '选择此项将固定控件显示宽度。';
    $lang->about_widget_width = '请输入宽度大小。';
    $lang->about_widget_position = '想要横向显示多个控件时，请选择位置。';
    $lang->about_widget_margin = '想要横向显示多个控件时，请设置边距。';
    $lang->about_widget_cache = '指定的时间内可以利用已缓冲的数据。';

    $lang->generated_code = '已生成的代码';

    $lang->msg_widget_is_not_exists = '找不到%s控件！';
    $lang->msg_widget_object_is_null = '无法生成%s控件对象！';
    $lang->msg_widget_proc_is_null = '不能执行%s控件的 proc()！';

    $lang->about_widget_code = '输入被选控件所需要的下列各项后，按『代码生成』按钮，即可在页面下方获得可以用在布局模版代码片断。';
    $lang->about_widget_code_in_page = '输入下列各项必要值后，按『代码生成』按钮，即可把控件插入到页面当中。';
    $lang->about_widget = "控件是在布局或页面模块中使用的一种小部件。\n不仅可以关联内部模块或外部open api，而且通过设置可以用在多种用途。\n即使不使用Zeroboard XE的页面模块或布局模块，也可以通过『代码生成』功能直接可以添加相应控件。";

    $lang->cmd_content_insert = "添加内容";
    $lang->cmd_box_widget_insert = "添加控件盒";
    $lang->cmd_remove_all_widgets  = "清空内容";

    $lang->cmd_widget_size = "大小";
    $lang->cmd_widget_align = "对齐";
    $lang->cmd_widget_align_left = "左对齐";
    $lang->cmd_widget_align_right = "右对齐";
    $lang->cmd_widget_margin = "外边距";
    $lang->cmd_widget_padding = "内填充";
    $lang->cmd_widget_border = "边框";
    $lang->cmd_widget_border_solid = "实线";
    $lang->cmd_widget_border_dotted = "点线";
    $lang->cmd_widget_background_color = "背景色";
    $lang->cmd_widget_background_image_url = "背景图片";
    $lang->cmd_widget_background_image_repeat = "平铺";
    $lang->cmd_widget_background_image_no_repeat = "固定";
    $lang->cmd_widget_background_image_x_repeat = "横向平铺";
    $lang->cmd_widget_background_image_y_repeat = "纵向平铺";
    $lang->cmd_widget_background_image_x = "水平位置";
    $lang->cmd_widget_background_image_y = "垂直位置";
?>
